***TFR (Egypt)
*Caroline Krafft
*TFR Descripitves Egypt
*v14
*JOPE Revision Four
*November 8, 2019

set scheme s1mono

***********************************************************************************************
*Calculating TFRs
**********************************************************************************************

**************
*ELMPS 2012
***************

use "elmps12_indiv CK v1.2 w educ.dta", clear

*Doing for the past 10 years by year
*Can aggregate for any subset of years

*Calculating TFR
*For each age group--age specific fertility
*Numerator is live births in past X years (2011 back)
*By five-year age group of mother
*Denominators are the number of woman-years lived in each of the specified five- year age groups in the period X years prior to the survey 


*Data universe is 18-49 in 2012

keep if sex==2

expand 10

bysort indid: gen year=2001+_n

sum q7210*
tabu q7210m_1
*Too many unkowns, doing year

*Loop for each year

foreach num2 of numlist 2002/2011 {

gen liveb_`num2'=0

foreach num of numlist 1/16 {
replace liveb_`num2'=liveb_`num2'+1 if q7210y_`num'==`num2' & year==`num2' 
}
}

*Live births, all ten years

gen live_b=0

foreach num2 of numlist 2002/2011 {
replace live_b=liveb_`num2' if year==`num2'
}

gen yr_age=year-brthyr

*Keeping 15-49 in that year?
drop if yr_age>49
drop if yr_age<15

recode yr_age (0/4=1)(5/9=2)(10/14=3)(15/19=4)(20/24=5)(25/29=6)(30/34=7)(35/39=8)(40/44=9) ///
           (45/49=10) (50/54=11) (55/59=12) (60/64=13) (65/69=14) (70/74=15) (75/max=16), gen(agegrp3)

label define Lagegrp3 1 "0-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" ///
6 "25-29" 7 "30-34" 8 "35-39" 9 "40-44" 10 "45-49" 11 "50-54" 12 "55-59" ///
13 "60-64" 14 "65-69" 15 "70-74" 16 "75+"

label values agegrp3 Lagegrp3

*Ever worked in public sector
gen evr_pub=0

replace evr_pub=1 if ussectrp>=1 & ussectrp<=2
replace evr_pub=1 if job1_05>=1 & job1_05 <=2
replace evr_pub=1 if job2_05>=1 & job2_05 <=2
replace evr_pub=1 if job3_05>=1 & job3_05 <=2
replace evr_pub=1 if job4_05>=1 & job4_05 <=2

tabu evr_pub, miss


*Yearly

table agegrp3 [aw=expan_12], c(mean live_b)
table agegrp3 year [aw=expan_12], c(mean live_b)

*Religion
table agegrp3 q7106 [aw=expan_12], c(mean live_b)
table agegrp3 year q7106 [aw=expan_12], c(mean live_b)

table agegrp3 q7106 if year>=2002 & year<=2006 [aw=expan_12], c(mean live_b)
table agegrp3 q7106 if year>=2007 & year<=2011 [aw=expan_12], c(mean live_b)

*3 year 2009-2011

table agegrp3 educ2 [aw=expan_12] if year>=2009 & year<=2011, c(mean live_b)


*3 year 2009-2011 by characteristics
clonevar mteducst2=mteducst
replace mteducst2=6 if mteducst2==7

clonevar fteducst2=fteducst
replace fteducst2=6 if fteducst2==7

*Feeds into Table 1`

*ASFRs

tabout evr_pub educ2 qwealth mteducst2 fteducst2 urban region gov agegrp3 ///
[aw=expan_12] if year>=2009 & year<=2011 ///
using "ASFRs by char 2012.xls" ///
, c(mean live_b) sum replace f(4) lines(none) ptotal(single)

*Column percentages

tabout evr_pub educ2 qwealth mteducst2 fteducst2 urban region gov ///
[aw=expan_12] if year>=2009 & year<=2011 ///
using "ASFRs by char col 2012.xls" ///
, c(col) oneway replace f(1) lines(none) ptotal(single)

*ASFRs for gen2
table agegrp3 [aw=expan_12] if educ2==5 & year>=2009 & year<=2011, c(mean live_b)


*ASFRs for non-students 
table agegrp3 [aw=expan_12] if student!=1 & educ2==5 & year>=2009 & year<=2011, c(mean live_b)

tabu student if educ2==5 [aw=expan_12]


/*
program drop _all

program define myprog1

preserve

expand 2 

bysort indid year: gen obs=_n

tabu obs

replace educ2=9 if obs==2

collapse live_b if year>=2009 & year<=2011 [pw=expan], by(educ2 agegrp3)

egen TFR=sum(live_b), by(educ2)
replace TFR=TFR*5

foreach num of numlist 1/9 {
sum TFR if educ2==`num' 
scalar s`num'=r(mean)
}

restore

end

bootstrap s1 s2 s3 s4 s5 s6 s7 s8 s9, ///
reps(400) cluster(psu) idcluster(newpsu) group(indid): myprog1

clear
*/

********************* 
****ELMPS 2006 data
*********************

*Ever married 16-49

use "ELMPS 2006 v4.2.dta", clear

merge 1:1 pn hhid using "comptbl 88__12 v1.dta"

tabu _merge

drop if _merge!=3

keep if sex==2

expand 10

bysort indid: gen year=1995+_n

sum q7004*
tabu q7004m1
*Too many unkowns, doing year

*Loop for each year

foreach num2 of numlist 1996/2005 {

gen liveb_`num2'=0

foreach num of numlist 1/13 {
replace liveb_`num2'=liveb_`num2'+1 if q7004y`num'==`num2' & year==`num2' 
}
}

*Live births, all ten years

gen live_b=0

foreach num2 of numlist 1996/2005 {
replace live_b=liveb_`num2' if year==`num2'
}

gen yr_age=year-q0103y

*Keeping 15-49 in that year?
drop if yr_age>49
drop if yr_age<15



recode yr_age (0/4=1)(5/9=2)(10/14=3)(15/19=4)(20/24=5)(25/29=6)(30/34=7)(35/39=8)(40/44=9) ///
           (45/49=10) (50/54=11) (55/59=12) (60/64=13) (65/69=14) (70/74=15) (75/max=16), gen(agegrp3)

label define Lagegrp3 1 "0-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" ///
6 "25-29" 7 "30-34" 8 "35-39" 9 "40-44" 10 "45-49" 11 "50-54" 12 "55-59" ///
13 "60-64" 14 "65-69" 15 "70-74" 16 "75+"

label values agegrp3 Lagegrp3

*Ever worked in public sector
gen evr_pub=0

replace evr_pub=1 if ussectrp>=1 & ussectrp<=2
replace evr_pub=1 if job1_05>=1 & job1_05 <=2
replace evr_pub=1 if job2_05>=1 & job2_05 <=2
replace evr_pub=1 if job3_05>=1 & job3_05 <=2

tabu evr_pub, miss

*By year

table agegrp3 [aw=expan], c(mean live_b)
table agegrp3 year [aw=expan], c(mean live_b)

*2006 past 3 years

table agegrp3 [aw=expan] if year>=2003 & year<=2005, c(mean live_b)


*3 year 2009-2011 by characteristics
clonevar mteducst2=mteducst
replace mteducst2=6 if mteducst2==7

clonevar fteducst2=fteducst
replace fteducst2=6 if fteducst2==7

*Feeds into Table 1

*ASFRs
tabout evr_pub educ2 qwealth mteducst2 fteducst2 urban region gov agegrp3 ///
[aw=expan] if year>=2003 & year<=2005 ///
using "ASFRs by char 2006.xls" ///
, c(mean live_b) sum replace f(4) lines(none) ptotal(single)

*Percentage of women

tabout evr_pub educ2 qwealth mteducst2 fteducst2 urban region gov ///
[aw=expan] if year>=2003 & year<=2005 ///
using "ASFRs by char col 2006.xls" ///
, c(col) oneway replace f(1) lines(none) ptotal(single)

*ASFRs for gen2
table agegrp3 [aw=expan] if educ2==5 & year>=2003 & year<=2005, c(mean live_b)


*ASFRs for non-students 
table agegrp3 [aw=expan] if student!=1 & educ2==5 & year>=2003 & year<=2005, c(mean live_b)

tabu student if educ2==5 [aw=expan]

/*
program drop _all

program define myprog1

preserve

expand 2 

bysort indid year: gen obs=_n

tabu obs

replace educ2=9 if obs==2

collapse live_b if year>=2003 & year<=2005 [pw=expan], by(educ2 agegrp3)

egen TFR=sum(live_b), by(educ2)
replace TFR=TFR*5

foreach num of numlist 1/9 {
sum TFR if educ2==`num' 
scalar s`num'=r(mean)
}

restore

end

bootstrap s1 s2 s3 s4 s5 s6 s7 s8 s9, ///
reps(400) cluster(psu) idcluster(newpsu) group(indid): myprog1

clear
*/

**********************
*Age at first birth
**********************

use "elmps12_indiv CK v1.2 w educ.dta", clear

keep if sex==2
keep if age>=18 & age<=49

gen ageb_1=q7210y_1-brthyr if q7210y_1!=9998

gen hadb_1=0 if q7210y_1!=9998
replace hadb_1=1 if ageb_1!=.

replace ageb_1=age if hadb_1==0 & q7210y_1!=9998
replace ageb_1=. if ageb_1>age

tabu ageb_1 hadb_1

stset ageb_1 [pw=expan_12], failure(hadb_1==1)
stsum

stsum, by(brthyr)

recode age (0/4=1)(5/9=2)(10/14=3)(15/19=4)(20/24=5)(25/29=6)(30/34=7)(35/39=8)(40/44=9) ///
           (45/49=10) (50/54=11) (55/59=12) (60/64=13) (65/69=14) (70/74=15) (75/max=16), gen(agegrp3)

label define Lagegrp3 1 "0-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" ///
6 "25-29" 7 "30-34" 8 "35-39" 9 "40-44" 10 "45-49" 11 "50-54" 12 "55-59" ///
13 "60-64" 14 "65-69" 15 "70-74" 16 "75+"

label values agegrp3 Lagegrp3


stsum, by(agegrp3)

********************************************
*Median age at first and birth marriage--Females
********************************************

use "elmps12_indiv CK v1.2 w educ.dta", clear

***Age at FIRST marriage by YOB

gen agemarr=m1srt-q103y if q103y!=9998

keep if age>=15 & age<=49

forvalues i=15(1)39  {
gen marr`i'=agemarr<=`i'
}

***Age at X birth by YOB

foreach bnum of numlist 1 2 3 {

gen ageb_`bnum'=q7210y_`bnum'-brthyr if `bnum'!=9998

forvalues i=15(1)39  {
gen brth`i'_`bnum'=ageb_`bnum'<=`i'
}
}

keep marr* brth* brthyr sex age expan_12 indid

reshape long marr@ brth@_1 brth@_2 brth@_3, i(indid) j(mar_age)

replace marr=. if age-mar_age<0

foreach bnum of numlist 1 2 3 {
replace brth_`bnum'=. if age-mar_age<0
}

label values mar_age
label variable mar_age "Yr. of age"

collapse marr brth_1 brth_2 brth_3 [pw=expan_12], by(sex mar_age brthyr)

keep if sex==2

*Percentiles for marriage
gen p50=.

sort sex brthyr mar_age

forvalues i=15(1)39 {
bysort sex brthyr: replace p50=`i' if mar_age==`i' & marr[_n]>=.5 & marr[_n-1]<.5 & marr[_n]!=.
}

egen mp50=max(p50), by(sex brthyr)

*Percentiles for births

foreach bnum of numlist 1 2 3 {

gen b_`bnum'_50=.

sort sex brthyr mar_age

forvalues i=15(1)39 {
bysort sex brthyr: replace b_`bnum'_50=`i' if mar_age==`i' & brth_`bnum'[_n]>=.5 & brth_`bnum'[_n-1]<.5 & brth_`bnum'[_n]!=.
}

egen mb_`bnum'_50=max(b_`bnum'_50), by(sex brthyr)

}
keep brthyr mp* mb*

duplicates drop brthyr, force


*Figure 5: Medians

graph twoway lowess mp50 brthyr, bw(1) lcolor(gs1) lpattern("l") ///
yscale(range(20 35)) ylabel(20(3)35) ytick(20(3)35) ///
xscale(range(1960 1990)) xlabel(1960(10)1990) xtick(1960(10)1990) || ///
lowess mb_1_50 brthyr, bw(1) lcolor(gs1) lpattern(shortdash) || ///
lowess mb_2_50 brthyr, bw(1) lcolor(gs5) lpattern(dash) || ///
lowess mb_3_50 brthyr, bw(1) lcolor(gs10) lpattern(shortdash) || ///
|| , legend(rows(2) order(1 "First Marriage" 2 "First birth" 3 "Second birth" 4 "Third birth")) ///
title("") xtitle("Year of Birth") ytitle("Age") plotregion(margin(none))

graph save "EG F YOB marr birth.gph", replace
graph export "EG F YOB marr birth.tif", replace

*********************
*Employment patterns
*********************

*****************************************
*Figure 3: Time trend 25-39 
*****************************************

use "elmps12_indiv CK v1.2 w educ.dta", clear

merge 1:m indid using "Egypt employ indiv ts.dta"

tabu _merge

gen i_public_100=i_public*100

gen age_year=year-brthyr
tabu age_year

table year sex if age_year>=25 & age_year<=39 [aw=expan], c(mean i_public_100) row col

*****************************************
*Figure 4: Employment rates by education
*****************************************

use "elmps 2012 comptbl 88_12 v2.3.dta", clear

keep if sex==2 & age>=15 & age<=64

drop if round==1988

replace cremp1=cremp1*100

gen pub=(crsectrp==1 | crsectrp==2)*100 if cremp1!=.

preserve

collapse cremp1 pub [aw=expan], by(age round educ2)

drop if cremp==. | age ==. | educ2==.

la def educ2 1 "Illiterate" 2 "Read & Write" 3 "Primary" 4 "Preparatory" 5 "General Secondary" ///
6 "Vocational Secondary" 7 "Post-secondary Institutes" 8 "University & Above", modify

graph twoway lowess cremp1 age if round==1998, ///
 bw(1) lcolor(gs13) lpattern("l") plotregion(margin(b=0)) mean || ///
 lowess cremp1 age if round==2006, ///
 bw(1) lcolor(gs7) lpattern("l") plotregion(margin(b=0)) mean || ///
 lowess cremp1 age if round==2012, ///
 bw(1) lcolor(gs3) lpattern("l") plotregion(margin(b=0)) mean || ///
 lowess pub age if round==1998, ///
 bw(1) lcolor(gs13) lpattern(dash) plotregion(margin(b=0)) mean || ///
 lowess pub age if round==2006, ///
 bw(1) lcolor(gs7) lpattern(dash) plotregion(margin(b=0)) mean || ///
 lowess pub age if round==2012, ///
 bw(1) lcolor(gs3) lpattern(dash) plotregion(margin(b=0)) mean || ///
 , by(educ2, note("") rows(4)) ///
 ytick(0 (20) 80) ylabel(0 (20) 80, nogrid) ///
 ysc(range(0 80)) xtitle("Age") ytitle("Percentage of pop.") ///
 xtick(15 (10) 65) xlabel(15 (10) 65) ///
 legend(label(1 "1998 Emp.") label(2 "2006 Emp.") label(3 "2012 Emp.") ///
 label(4 "1998 Pub.") label(5 "2006 Pub.") label(6 "2012 Pub.") size(3) span row(2))

graph display, xsize(12) ysize(20)

graph save "Emp age ed.gph", replace
graph export "Emp age ed.tif", replace

restore

*****************************************
*Table 9: Employment and public sector
*****************************************

drop if cremp1==. | age ==. | educ2==.

egen age_ed=group(educ2 agegrp2), label

tabout age_ed round ///
[aw=expan] using "emp rep xs.xls" ///
, c(mean cremp1) ///
 sum replace f(1) lines(none) ptotal(single)

tabout educ2 round ///
[aw=expan] using "emp rep xs.xls" ///
, c(mean cremp1) ///
 sum append f(1) lines(none) ptotal(single)
 
 
 tabout age_ed round ///
[aw=expan] using "emp rep xs.xls" ///
, c(mean pub) ///
 sum append f(1) lines(none) ptotal(single)

 tabout educ2 round ///
[aw=expan] using "emp rep xs.xls" ///
, c(mean pub) ///
 sum append f(1) lines(none) ptotal(single)
 
 

*G2 stat:
use "elmps12_indiv CK v1.2 w educ.dta", clear

tabu educ2 if sex==2 & age>=15 & age<=64 [aw=expan]
tabu educ2 if sex==2 & age>=15 & age<=64 & student==2 [aw=expan]
tabu student if sex==2 & age>=15 & age<=64 & educ2==5 [aw=expan]

