***TFR (Egypt)
*Caroline Krafft
***TFR Models
*v44
*May 25, 2019

*******************************************************************************
*Models
*******************************************************************************

estimates clear
program drop _all
set scheme s1mono

*************
***Full sample
*************

use "TFR Models Full Sample.dta", clear

keep if year>=1990 & year<=2011

*Year groups and age groups, controlling for parity

logit next_born b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
b4.yr_agroup##b4.yr_group ///
, or cluster(psu) 

estimates store full1

margins,  over(yr_agroup yr_group) predict(pr) post 

estimates store fullm1

*****************************************
*Figure 6: Hazards by age group and calendar year
*****************************************

mplotoffset, xdim(yr_group) plotregion(margin(sides)) ///
xtitle("Year") ytitle("Hazard") ///
plot1opts(lcolor(gs14) lpatt("l") mcolor(gs14) msize(small))  ///
plot2opts(lcolor(gs12) lpatt("l") mcolor(gs12) msize(small))  ///
plot3opts(lcolor(gs10) lpatt("l") mcolor(gs10) msize(small))  ///
plot4opts(lcolor(gs8) lpatt("l") mcolor(gs8) msize(small))  ///
plot5opts(lcolor(gs6) lpatt("l") mcolor(gs6) msize(small))  ///
plot6opts(lcolor(gs4) lpatt("l") mcolor(gs4) msize(small))  ///
plot7opts(lcolor(gs1) lpatt("l") mcolor(gs1) msize(small))  ///
ci1opts(lcolor(gs14) lpatt("l") mcolor(gs14) msize(small))  ///
ci2opts(lcolor(gs12) lpatt("l") mcolor(gs12) msize(small))  ///
ci3opts(lcolor(gs10) lpatt("l") mcolor(gs10) msize(small))  ///
ci4opts(lcolor(gs8) lpatt("l") mcolor(gs8) msize(small))  ///
ci5opts(lcolor(gs6) lpatt("l") mcolor(gs6) msize(small))  ///
ci6opts(lcolor(gs4) lpatt("l") mcolor(gs4) msize(small))  ///
ci7opts(lcolor(gs1) lpatt("l") mcolor(gs1) msize(small))  ///
ylabel(0(.1).5) ytick(0(.1).5) xlabel() xtick() title("") ///
legend(title("Age group", size(4)) rows(2)) offset(0.02)

graph save "haz year_age bord.gph", replace
graph export "haz year_age bord.png", replace


esttab full1 using TFRtimemodel1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g))   ///
	nobase noomit ///
	indicate("Parity and yrs since last birth =*c_bord *c_int* _cons") ///
	eform replace

*Table 10
	
esttab fullm1 using TFRtimemargins1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g))   ///
	nobase noomit ///
	 replace

*****************************************
*Figure 9: Years and age groups, controlling for parity
*****************************************

logit next_born b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
b4.yr_agroup##b4.year ///
, or cluster(psu) 

margins,  over(year yr_agroup) predict(pr) post 	

mplotoffset, xdim(year) plotregion(margin(sides)) ///
xtitle("Year") ytitle("Hazard") ///
plot1opts(lcolor(gs14) lpatt("l") mcolor(gs14) msize(small))  ///
plot2opts(lcolor(gs12) lpatt("l") mcolor(gs12) msize(small))  ///
plot3opts(lcolor(gs10) lpatt("l") mcolor(gs10) msize(small))  ///
plot4opts(lcolor(gs8) lpatt("l") mcolor(gs8) msize(small))  ///
plot5opts(lcolor(gs6) lpatt("l") mcolor(gs6) msize(small))  ///
plot6opts(lcolor(gs4) lpatt("l") mcolor(gs4) msize(small))  ///
plot7opts(lcolor(gs1) lpatt("l") mcolor(gs1) msize(small))  ///
ci1opts(lcolor(gs14) lpatt("l") mcolor(gs14) msize(small))  ///
ci2opts(lcolor(gs12) lpatt("l") mcolor(gs12) msize(small))  ///
ci3opts(lcolor(gs10) lpatt("l") mcolor(gs10) msize(small))  ///
ci4opts(lcolor(gs8) lpatt("l") mcolor(gs8) msize(small))  ///
ci5opts(lcolor(gs6) lpatt("l") mcolor(gs6) msize(small))  ///
ci6opts(lcolor(gs4) lpatt("l") mcolor(gs4) msize(small))  ///
ci7opts(lcolor(gs1) lpatt("l") mcolor(gs1) msize(small))  ///
ylabel(0(.1).6) ytick(0(.1).5) xlabel(, angle(90)) xtick() title("") ///
legend(title("Age group", size(4)) rows(2)) offset(0.02)

graph save "haz sing year_age bord.gph", replace
graph export "haz sing year_age bord.png", replace



*************
*Reference baseline hazards
*************

use "TFR Models.dta", clear

*Reference baseline hazards

logit next_born b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length, or cluster(psu) 

estimates store est1 

*************
*Own emp 
*************


*Model with own contemporaneous employment status, births 

logit next_born i.i_public b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length, or cluster(psu) 

estimates store est2


*************
*Own emp w/ controls
*************

/*Model with own contemporaneous employment status, births, age groups
education level, mother's education, father's education, life expectancy, 
literacy, gdp per capita, geographic differences */


logit next_born b0.i_public ///
i.have_male b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
b4.yr_agroup##b4.yr_group ///
, or cluster(psu) 

estimates store est5


/*Model with own contemporaneous employment status INTERACTED with birth order
births, age groups
education level, mother's education, father's education, life expectancy, 
literacy, gdp per capita, geographic differences */

logit next_born b0.i_public_ord ///
i.have_male b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
b4.yr_agroup##b4.yr_group  ///
, or cluster(psu) 

estimates store est6

/* Adding Spouse */

logit next_born b0.i_public_ord ///
i.have_male b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
b0.sp_i_public_ord b1.sp_educ2 b4.sp_yr_agroup ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
b4.yr_agroup##b4.yr_group  ///
, or cluster(psu) 

estimates store spest6


*Adding interacted have male

logit next_born b0.i_public_ord b0.male_ord b0.male_i_pub_ord ///
b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
 b4.yr_agroup##b4.yr_group  ///
, or cluster(psu) 

estimates store est6male


*****************
*3SRI
*****************



*First stage probit
probit i_public c.public_100 c.l1public_100 c.l2public_100 b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov  b4.yr_agroup b4.yr_agroup#b4.yr_group b1991.year, ///
cluster(psu)

estimates store IVFS1

test public_100 l1public_100 l2public_100

predict prob, pr
*Because of perfect predictors, replacing if missing
replace prob=0 if prob==. & public_100!=. & l1public_100!=. & l2public_100!=.

margins, dydx(*) post

estimates store FS3SRI

*First stage LPM
regress i_public prob b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov  b4.yr_agroup b4.yr_agroup#b4.yr_group b1991.year , ///
cluster(psu)

test prob

drop prob




***program

program define e3SRI, eclass

preserve


*First stage probit
probit i_public c.public_100 c.l1public_100 c.l2public_100 b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov b4.yr_agroup b4.yr_agroup#b4.yr_group b1991.year, ///
cluster(psu)


predict prob, pr
*Because of perfect predictors, replacing if missing
replace prob=0 if prob==. & public_100!=. & l1public_100!=. & l2public_100!=.

*First stage LPM
regress i_public prob b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov b4.yr_agroup b4.yr_agroup#b4.yr_group b1991.year, ///
cluster(psu)

predict prob2
gen resid=i_public-prob2

*Second stage: Include residuals and endogenoues regressor 

logit next_born b0.i_public_ord c.resid c.resid#b0.c_bord ///
 i.have_male b1.educ2 /// 
b1.mteducst2 b1.fteducst2 ///
c.life c.lit c.gdppc c.prenataly ///
b1.burban#b1.bgov b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
b4.yr_agroup b4.yr_agroup#b4.yr_group b1991.year ///
, or  cluster(psu) 

restore

end

*Run program

e3SRI


sort indid year

set seed 923743

bootstrap _b, ///
eform reps(400) cluster(psu) idcluster(newpsu) group(indid): e3SRI

estimates store RIbs1

*****************
*Fixed effects
*****************

use "TFR Models.dta", clear

set seed 8912370

sort indid year

*Interacted public and parity

clogit next_born i.i_public_ord ///
i.have_male ///
c.life c.lit c.gdppc c.prenataly ///
b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length ///
b4.yr_agroup##b4.yr_group ///
,  or    group(indid)

estimates store FE2

*Adding interaction with son

clogit next_born b0.i_public_ord b0.male_ord b0.male_i_pub_ord ///
c.life c.lit c.gdppc c.prenataly ///
b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length b4.yr_agroup##b4.yr_group ///
,  or    group(indid)

estimates store FE2male

*Reduced form (local opportunities)

clogit next_born c.public_100 c.public_100#b0.c_bord ///
i.have_male ///
c.life c.lit c.gdppc c.prenataly ///
b0.c_bord b1.c_int_length b0.c_bord#b1.c_int_length b4.yr_agroup##b4.yr_group ///
, or    group(indid)

estimates store FE4





********************
*Estimates output
********************

*Table 2

esttab est2 est5 est6 using TFRmodelsv1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g))   ///
	legend  mlabel("Spec. 1" "Spec. 2" "Spec. 3" ) ///
	order(1.i_public 1.i_public_ord 2.i_public_ord  3.i_public_ord  4.i_public_ord  5.i_public_ord ///
	6.i_public_ord ) ///
	coeflabels(1.i_public "Working in public sector" ///
	 1.have_male "Yes" 2.educ2 "Read and Write" 3.educ2 "Primary" 4.educ2 "Preparatory" ///
	 5.educ2 "General Secondary" 6.educ2 "Vocational Secondary" 7.educ2 ///
 	"Post-Sec. Inst." 8.educ2 "Univ. & Above" ///
	2.mteducst2 "Read and Write" 3.mteducst2 "Less than Secondary" 4.mteducst2 "Secondary" ///
	5.mteducst2 "Post-Sec. Inst." 6.mteducst2 "University and above" ///
	2.fteducst2 "Read and Write" 3.fteducst2 "Less than Secondary" 4.fteducst2 "Secondary" ///
	5.fteducst2 "Post-Sec. Inst." 6.fteducst2 "University and above"	///
	life "Life Expectancy (years)" lit "Adult Lit." gdppc "GDP per capita (thousand LE)" ///
	prenataly "Prenatal care" ///
	1.i_public_ord "Marriage" 2.i_public_ord "First birth" 3.i_public_ord "Second birth" 4.i_public_ord "Third birth" ///
	5.i_public_ord "Fourth birth" 6.i_public_ord "Fifth birth and above") ///
	refcat(2.by_coh "Birth cohort (1970-1974 omit.)" 2.educ2 "Education (illit. omit)" 1.yr_agroup "Age group (30-34 omit.)" 2.mteducst2 "Mother's ed. (illit. omit)" ///
	2.fteducst2 "Father's ed. (illit. omit)" life "Governorate chars."  ///
	1.i_public_ord "Public sector work interacted with parity" ///
	1.have_male "Have a male child (not yet omit.)" )       ///
	nobase ///
	indicate("Parity and yrs since last birth =*c_bord* *c_int* _cons" "Birth gov and urban int= *burban*" ///
	"Age group and cal. year group ints = *group") ///
	eform replace

*Table 11
esttab spest6 using TFRmodelsSPv1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g))   ///
	legend  ///
	order(1.i_public_ord 2.i_public_ord  3.i_public_ord  4.i_public_ord  5.i_public_ord ///
	6.i_public_ord ) ///
	coeflabels(	 1.have_male "Yes" 2.educ2 "Read and Write" 3.educ2 "Primary" 4.educ2 "Preparatory" ///
	 5.educ2 "General Secondary" 6.educ2 "Vocational Secondary" 7.educ2 ///
 	"Post-Sec. Inst." 8.educ2 "Univ. & Above" ///
	 2.sp_educ2 "Read and Write" 3.sp_educ2 "Primary" 4.sp_educ2 "Preparatory" ///
	 5.sp_educ2 "General Secondary" 6.sp_educ2 "Vocational Secondary" 7.sp_educ2 ///
 	"Post-Sec. Inst." 8.sp_educ2 "Univ. & Above" ///
 	1.sp_yr_agroup "<20" 2.sp_yr_agroup "20-24" ///
	3.sp_yr_agroup "25-29" 5.sp_yr_agroup "35-39" 6.sp_yr_agroup "40-44" 7.sp_yr_agroup "45-49" ///
	2.mteducst2 "Read and Write" 3.mteducst2 "Less than Secondary" 4.mteducst2 "Secondary" ///
	5.mteducst2 "Post-Sec. Inst." 6.mteducst2 "University and above" ///
	2.fteducst2 "Read and Write" 3.fteducst2 "Less than Secondary" 4.fteducst2 "Secondary" ///
	5.fteducst2 "Post-Sec. Inst." 6.fteducst2 "University and above"	///
	life "Life Expectancy (years)" lit "Adult Lit." gdppc "GDP per capita (thousand LE)" ///
	prenataly "Prenatal care" ///
	1.i_public_ord "Marriage" 2.i_public_ord "First birth" 3.i_public_ord "Second birth" 4.i_public_ord "Third birth" ///
	5.i_public_ord "Fourth birth" 6.i_public_ord "Fifth birth and above" ///
	1.sp_i_public_ord "Marriage" 2.sp_i_public_ord "First birth" 3.sp_i_public_ord "Second birth" 4.sp_i_public_ord "Third birth" ///
	5.sp_i_public_ord "Fourth birth" 6.sp_i_public_ord "Fifth birth and above" ) ///
	refcat(2.by_coh "Birth cohort (1970-1974 omit.)" 2.educ2 "Education (illit. omit)" 2.sp_educ2 "Spouse education (illit. omit)" ///
	1.yr_agroup "Age group (30-34 omit.)" 2.mteducst2 "Mother's ed. (illit. omit)" ///
	1.sp_yr_agroup "Spouse age group (30-34 omit.)" ///
	2.fteducst2 "Father's ed. (illit. omit)" life "Governorate chars."  ///
	1.i_public_ord "Public sector work interacted with parity" ///
	1.sp_i_public_ord "Spouse public sector work interacted with parity" ///
	1.have_male "Have a male child (not yet omit.)" )       ///
	nobase ///
	indicate("Parity and yrs since last birth =*c_bord* *c_int* _cons" "Birth gov and urban int= *burban*" ///
	"Age group and cal. year group ints = *group") ///
	eform replace


*Table 13

esttab FS3SRI using TFRIVFSmodelsv1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N r2, fmt(%9.0g %9.3g) label("N" "R-squared"))   ///
	coeflabels(1.yr_agroup "<20" 2.yr_agroup "20-24" ///
	3.yr_agroup "25-29" 5.yr_agroup "35-39" 6.yr_agroup "40-44" 7.yr_agroup "45-49" ///
	2.by_coh "1950-1964" 3.by_coh "1965-1969" 5.by_coh "1975-1979" 6.by_coh "1980-1984" ///
	 7.by_coh "1985-1990" 8.by_coh "1990-1997" ///
	 1.have_male "Yes" 2.educ2 "Read and Write" 3.educ2 "Primary" 4.educ2 "Preparatory" ///
	 5.educ2 "General Secondary" 6.educ2 "Vocational Secondary" 7.educ2 ///
 	"Post-Sec. Inst." 8.educ2 "Univ. & Above" ///
	2.mteducst2 "Read and Write" 3.mteducst2 "Less than Secondary" 4.mteducst2 "Secondary" ///
	5.mteducst2 "Post-Sec. Inst." 6.mteducst2 "University and above" ///
	2.fteducst2 "Read and Write" 3.fteducst2 "Less than Secondary" 4.fteducst2 "Secondary" ///
	5.fteducst2 "Post-Sec. Inst." 6.fteducst2 "University and above"	///
	life "Life Expectancy (years)" lit "Adult Lit." gdppc "GDP per capita (thousand LE)" ///
	prenataly "Prenatal care" public_100 "Public sector local emp. (percentage)" ///
		_cons "Constant") ///
	refcat(2.by_coh "Birth cohort (1970-1974 omit.)" 2.educ2 "Education (illit. omit)" 1.yr_agroup "Age group (30-34 omit.)" 2.mteducst2 "Mother's ed. (illit. omit)" ///
	2.fteducst2 "Father's ed. (illit. omit)" life "Governorate chars."  ///
	1.have_male "Have a male child (not yet omit.)" )       ///
	nobase ///
	indicate( "Birth gov and urban int= *burban* *bgov*" "Age group and cal. year group ints = *group" ///
	"Single years = *year") ///
	replace


esttab RIbs1 using TFRIVSSmodelsv1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g))   ///
	legend  mlabel("2SRI" "2SPS" ) ///
	coeflabels(1.i_public "Working in public sector" ///
	  1.have_male "Yes" 2.educ2 "Read and Write" 3.educ2 "Primary" 4.educ2 "Preparatory" ///
	 5.educ2 "General Secondary" 6.educ2 "Vocational Secondary" 7.educ2 ///
 	"Post-Sec. Inst." 8.educ2 "Univ. & Above" ///
	2.mteducst2 "Read and Write" 3.mteducst2 "Less than Secondary" 4.mteducst2 "Secondary" ///
	5.mteducst2 "Post-Sec. Inst." 6.mteducst2 "University and above" ///
	2.fteducst2 "Read and Write" 3.fteducst2 "Less than Secondary" 4.fteducst2 "Secondary" ///
	5.fteducst2 "Post-Sec. Inst." 6.fteducst2 "University and above"	///
	life "Life Expectancy (years)" lit "Adult Lit." gdppc "GDP per capita (thousand LE)" ///
	prenataly "Prenatal care" ///
	1.i_public_ord "Marriage" 2.i_public_ord "First birth" 3.i_public_ord "Second birth" 4.i_public_ord "Third birth" ///
	5.i_public_ord "Fourth birth" 6.i_public_ord "Fifth birth and above" ///
	resid "Marriage" 1.c_bord#c.resid "First birth" 2.c_bord#c.resid "Second birth" ///
	3.c_bord#c.resid "Third birth" 4.c_bord#c.resid "Fourth birth" 5.c_bord#c.resid "Fifth birth and above") ///
	refcat(2.by_coh "Birth cohort (1970-1974 omit.)" 2.educ2 "Education (illit. omit)" 1.yr_agroup "Age group (30-34 omit.)" 2.mteducst2 "Mother's ed. (illit. omit)" ///
	2.fteducst2 "Father's ed. (illit. omit)" life "Governorate chars."  ///
	1.i_public_ord "Public sector work interacted with parity" ///
	resid "Residual for public sector work interacted with parity" ///
	1.have_male "Have a male child (not yet omit.)")       ///
	nobase ///
	indicate("Parity and yrs since last birth =*c_bord *c_int* _cons" "Birth gov and urban int= *burban*" ///
	"Age group and cal. year group ints = *group" ///
	"Single years = *year") ///
	eform replace






esttab FE2 FE4 using TFRFEmodelsv1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g))   ///
	legend  mlabel("Spec. 4" "Spec. 5" ) ///
	order(1.i_public_ord 2.i_public_ord  3.i_public_ord  4.i_public_ord  5.i_public_ord ///
	6.i_public_ord c.public_100 1.c_bord#c.public_100 2.c_bord#c.public_100 3.c_bord#c.public_100 4.c_bord#c.public_100 ///
	5.c_bord#c.public_100 ) ///
	coeflabels(	1.have_male "Yes" life "Life Expectancy (years)" lit "Adult Lit." gdppc "GDP per capita (thousand LE)" ///
	prenataly "Prenatal care"  ///
	1.i_public_ord "Marriage" 2.i_public_ord "First birth" 3.i_public_ord "Second birth" 4.i_public_ord "Third birth" ///
	5.i_public_ord "Fourth birth" 6.i_public_ord "Fifth birth and above" ///
	public_100 "Marriage" 1.c_bord#c.public_100 "First birth" 2.c_bord#c.public_100 "Second birth" 3.c_bord#c.public_100 "Third birth" ///
	4.c_bord#c.public_100 "Fourth birth" 5.c_bord#c.public_100 "Fifth birth and above" ///
	) ///
	refcat(1.yr_agroup "Age group (30-34 omit.)" life "Governorate chars."  ///
	1.i_public_ord "Public sector work interacted with parity" ///
	public_100 "Public sector local emp. (percentage) interacted with parity" ///
	1.have_male "Have a male child (not yet omit.)")       ///
	nobase ///
	indicate("Parity and yrs since last birth =*c_bord *c_int*" "Age group and cal. year group ints = *group" ) ///
	eform replace

*Table 12
	
esttab est6male FE2male using TFRmaleintmodelsv1.csv, cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g))   ///
	legend  mlabel("Spec. 6" "Spec. 7") ///
	order(1.i_public_ord 2.i_public_ord  3.i_public_ord  4.i_public_ord  5.i_public_ord ///
	6.i_public_ord 1.male_i_pub_ord 2.male_i_pub_ord 3.male_i_pub_ord ///
	4.male_i_pub_ord 5.male_i_pub_ord 1.male_ord 2.male_ord 3.male_ord 4.male_ord 5.male_ord) ///
	coeflabels(	1.have_male "Yes" life "Life Expectancy (years)" lit "Adult Lit." gdppc "GDP per capita (thousand LE)" ///
	prenataly "Prenatal care"  ///
	1.i_public_ord "Marriage" 2.i_public_ord "First birth" 3.i_public_ord "Second birth" 4.i_public_ord "Third birth" ///
	5.i_public_ord "Fourth birth" 6.i_public_ord "Fifth birth and above" ///
	1.male_i_pub_ord "First birth" 2.male_i_pub_ord "Second birth" 3.male_i_pub_ord "Third birth" ///
	4.male_i_pub_ord "Fourth birth" 5.male_i_pub_ord "Fifth birth and above" ///
	1.male_ord "First birth" 2.male_ord "Second birth" 3.male_ord "Third birth" ///
	4.male_ord "Fourth birth" 5.male_ord "Fifth birth and above" ///
	 2.educ2 "Read and Write" 3.educ2 "Primary" 4.educ2 "Preparatory" ///
	 5.educ2 "General Secondary" 6.educ2 "Vocational Secondary" 7.educ2 ///
 	"Post-Sec. Inst." 8.educ2 "Univ. & Above" ///
	2.mteducst2 "Read and Write" 3.mteducst2 "Less than Secondary" 4.mteducst2 "Secondary" ///
	5.mteducst2 "Post-Sec. Inst." 6.mteducst2 "University and above" ///
	2.fteducst2 "Read and Write" 3.fteducst2 "Less than Secondary" 4.fteducst2 "Secondary" ///
	5.fteducst2 "Post-Sec. Inst." 6.fteducst2 "University and above"	///
	) ///
	refcat(2.educ2 "Education (illit. omit)" 1.yr_agroup "Age group (30-34 omit.)" 2.mteducst2 "Mother's ed. (illit. omit)" ///
	2.fteducst2 "Father's ed. (illit. omit)" life "Governorate chars."  ///
	1.i_public_ord "Public sector work interacted with parity" ///
	1.male_i_pub_ord "Public sector work interacted with parity and having a male" ///
	1.male_ord "Parity interacted with having a male" ///
	1.have_male "Have a male child (not yet omit.)")       ///
	nobase ///
	indicate("Parity and yrs since last birth =*c_bord *c_int* _cons" "Birth gov and urban int= *burban*" ///
	"Age group and cal. year group ints = *group") ///
	eform replace
