***TFR (Egypt)
*Caroline Krafft
***TFR Sims
*v20
*May 26, 2019

capture log close
log using "TFR Sims log 5.26.19.log", replace

********************
*Simulations
********************

*******************************************************************************
***Baseline on to full set of bord and intervals
*******************************************************************************

use "TFR Models.dta", clear
 
estimates restore est1


keep in 1
keep indid

expand 6

gen c_bord=_n-1

expand 10

bysort c_bord: gen c_int_length=_n

predict double base, pr

keep base c_int_length c_bord

reshape wide base, i(c_int_length) j(c_bord)

export excel using "Basehaz.xls", firstrow(variables) replace


*******************************************************************************
*Simple model own emp.
*******************************************************************************

***************
*Public sector
***************

use "TFR Models.dta", clear

*Public sector throughout
replace i_public=1

estimates restore est5

predict double base, pr

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "Logit simple pub.xls", firstrow(variables) replace

*****************
*No public sector
*****************

use "TFR Models.dta", clear

*No public sector throughout
replace i_public=0

estimates restore est5

predict double base, pr

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "Logit simple no pub.xls", firstrow(variables) replace


*******************************************************************************
*Interacted model own emp.
*******************************************************************************

***************
*Public sector
***************

use "TFR Models.dta", clear

*Public sector throughout
replace i_public_ord=c_bord+1

estimates restore est6

predict double base, pr

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "Logit int pub.xls", firstrow(variables) replace

******************
*No public sector
*******************

use "TFR Models.dta", clear

*No public sector throughout
replace i_public_ord=0

estimates restore est6

predict double base, pr

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "Logit int no pub.xls", firstrow(variables) replace




*******************************************************************************
*FE model--own emp interacted
*******************************************************************************

***************
*Public sector
***************

use "TFR Models.dta", clear

*Public sector throughout
replace i_public_ord=c_bord+1

estimates restore FE2

predict double base_pc1, pc1

egen ind_tot=sum(next_born), by(indid)

gen base=base_pc1*ind_tot

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "xt int pub.xls", firstrow(variables) replace



*******************
*Not public sector
*******************

use "TFR Models.dta", clear

*No public sector throughout
replace i_public_ord=0

estimates restore FE2

predict double base_pc1, pc1

egen ind_tot=sum(next_born), by(indid)

gen base=base_pc1*ind_tot

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)


export excel using "xt int no pub.xls", firstrow(variables) replace




******************************************************************************
*FE model--Rate interacted
******************************************************************************

*****************
*Public sector 10
*****************

use "TFR Models.dta", clear

replace public_100=10

estimates restore FE4

predict double base_pc1, pc1

egen ind_tot=sum(next_born), by(indid)

gen base=base_pc1*ind_tot

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "xt int rate 5.xls", firstrow(variables) replace


********************
*Public sector 0
********************

use "TFR Models.dta", clear

replace public_100=0

estimates restore FE4

predict double base_pc1, pc1

egen ind_tot=sum(next_born), by(indid)

gen base=base_pc1*ind_tot

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "xt int rate 0.xls", firstrow(variables) replace


*******************************************************************************
*IV model own emp. RI
*******************************************************************************

******************
*Public sector
******************

use "TFR Models.dta", clear

*Public sector throughout
replace i_public_ord=c_bord+1

gen resid=0

estimates restore RIbs1

predict double base, pr

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)

export excel using "IV RI pub.xls", firstrow(variables) replace



*********************
*No public sector
*********************

use "TFR Models.dta", clear

*Public sector throughout
replace i_public_ord=0

gen resid=0

estimates restore RIbs1

predict double base, pr

collapse (mean) base, by(c_int_length c_bord)

reshape wide base, i(c_int_length) j(c_bord)


export excel using "IV RI no pub.xls", firstrow(variables) replace




log close
