***TFR (Egypt)
*Caroline Krafft
***TFR Survival Data
*v6
*May 26, 2019

estimates clear

use "elmps12_indiv CK v1.2 w educ.dta", clear

set seed 1923812

keep age sex indid psu q7210y* q7209* expan_12 educ2 mteducst fteducst brthyr m1srt hhid spcode q7106

*Women who answered
keep if sex==2 & age>=18 & age<=49

gen q7210y_0=m1srt

reshape long q7210y_@ q7209_@, i(indid) j(bord)

*Drop if didn't have birth
keep if q7210y_!=.


*Drop if don't know year
drop if q7210y_==9998

*Dropping multiple in same year
duplicates report indid q7210y_
duplicates drop indid q7210y_, force

sort indid q7210y_ bord

*Number male and female

gen ch_male=0 if q7209_==2
replace ch_male=1 if q7209_==1

gen ch_female=1 if q7209_==2
replace ch_female=0 if q7209_==1

gen n_male=0 
bysort indid: replace n_male=sum(ch_male)

gen n_female=0 
bysort indid: replace n_female=sum(ch_female)
 
*Percent male 
gen percent_male=100*n_male/(n_male+n_female) 
replace percent_male=0 if percent_male==.

*Have male
gen have_male=(percent_male!=0)

*Year interval as a survival model
gen interval=.
replace interval=q7210y_[_n+1]-q7210y_[_n] if indid[_n]==indid[_n+1]

gen has_next=0
replace has_next=1 if interval!=.
replace interval=(2012-q7210y_) if interval==.

sum interval

table q7210y_ if has_next==1 [aw=expan_12], c(mean interval)

*Expand for each year in the interval

expand interval

bysort bord indid: gen int_length=_n

sort indid bord int_length

tabu int_length

*Failure
gen next_born=0
bysort indid bord: replace next_born=1 if has_next==1 & int_length==_N

*Generate a variable for the varying year
bysort indid bord: gen interval_year=floor((q7210y_+_n))

tabu interval_year

*Generating age in year

gen year_age=interval_year-brthyr

tabu year_age
*Small n improbable

*Age groups for age in year

gen yr_agroup=.
replace yr_agroup=1 if year_age>=0 & year_age<=19
replace yr_agroup=2 if year_age>=20 & year_age<=24
replace yr_agroup=3 if year_age>=25 & year_age<=29
replace yr_agroup=4 if year_age>=30 & year_age<=34
replace yr_agroup=5 if year_age>=35 & year_age<=39
replace yr_agroup=6 if year_age>=40 & year_age<=44
replace yr_agroup=7 if year_age>=45 & year_age<=49

la def Lyr_agroup 1 "<20" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" ///
6 "40-44" 7 "45-49"

la val yr_agroup Lyr_agroup

tabu yr_agroup, miss
tabu yr_agroup, gen(yra)

*Birth cohort
recode brthyr (1950/1964=2) (1965/1969=3) (1970/1974=4) (1975/1979=5) ///
(1980/1984=6) (1985/1989=7) (1990/1997=8), gen(by_coh)


*Parent's education
clonevar mteducst2=mteducst
replace mteducst2=6 if mteducst2==7

clonevar fteducst2=fteducst
replace fteducst2=6 if fteducst2==7

drop fteducst mteducst

*Birth id
label val bord 
tabu bord

tostring bord, gen(s_bord)
replace s_bord="0"+s_bord if bord<10

gen bid=indid+s_bord

*duplicates report bid int_length

*Aggregating higher intervals

tabu int_length next_born [aw=expan], row
tabu int_length next_born, row
*Past 10 years few generate births

tabu bord [aw=expan] if int_length==1
*Less than 5% past five births

gen c_bord=bord
replace c_bord=5 if c_bord>5 & c_bord<.

gen c_int_length=int_length
replace c_int_length=10 if c_int_length>10 & c_int_length<.

rename interval_year year

keep if year_age>=15 & year_age<=49

gen yr_group=1 if year>=1990 & year<=1994
replace yr_group=2 if year>=1995 & year<=1999
replace yr_group=3 if year>=2000 & year<=2004
replace yr_group=4 if year>=2005 & year<=2009
replace yr_group=5 if year>=2010 & year<=2011

la def Lyr_group 1 "1990-1994" 2 "1995-1999" 3 "2000-2004" ///
4 "2005-2009" 5 "2010-2011"

la val yr_group Lyr_group

save "TFR Models Full Sample.dta", replace 


***************************************
*Merging in economic opportunities
****************************************

merge m:1 indid year using "Egypt employ indiv ts.dta"

drop if _merge==1
tabu _merge

*Are using only before individual had children?
tabu _merge if _merge==2 & q7210y_1<year
*Almost all

tabu q7210y_* if _merge==2 & q7210y_1<year
*Remainder have missing year data

drop if _merge==2
drop _merge

gen public_100=public*100
gen l1public_100=l1public*100
gen l2public_100=l2public*100
gen Fpublic_100=Fpublic*100
gen Mpublic_100=Mpublic*100


replace gdppc=gdppc/1000

replace prenatal=prenatal*100


****Merge in spouse


merge m:1 hhid spcode year using "Egypt employ indiv spouse ts.dta"

tabu _merge
tabu _merge if bord==0 & int_length==1

drop if _merge==2

tabu _merge

drop _merge


*Interactions with birth order
gen i_public_ord=i_public*(c_bord+1)

gen sp_i_public_ord=sp_i_public*(c_bord+1)

gen evr_i_public_ord=ever_pub*(c_bord+1)

gen male_ord=have_male*c_bord

gen male_i_pub_ord=male_ord*i_public

tabu yr_agroup, gen(yr_ag_)

*Keeping only 1991-2011

keep if m1srt>=1991 & m1srt<.

keep if year>=1991 & year<=2011


**********************
*Summary statistics
**********************

***Table 6: Summary table

tabout educ2 mteducst2 fteducst2 burban bgov have_male i_public yr_agroup  by_coh ///
if expan!=. [aw= expan] using "TFR Sum Stat.xls", replace ///
c(col) lines(none) f(1) npos(row) oneway ptotal(single)

sum public_100 life lit gdppc prenataly [aw=expan]

*Centering variables

sum public_100 [aw=expan]
replace public_100=public_100-r(mean)

sum l1public_100 [aw=expan]
replace l1public_100=l1public_100-r(mean)

sum l2public_100 [aw=expan]
replace l2public_100=l2public_100-r(mean)

sum Mpublic_100 [aw=expan]
replace Mpublic_100=Mpublic_100-r(mean)

sum Fpublic_100 [aw=expan]
replace Fpublic_100=Fpublic_100-r(mean)


sum life [aw=expan]
replace life=life-r(mean)

sum lit [aw=expan]
replace lit=lit-r(mean)

sum gdppc [aw=expan]
replace gdppc=gdppc-r(mean)

sum prenataly [aw=expan]
replace prenataly=prenataly-r(mean)

sum public_100 life lit gdppc [aw=expan]

tabu c_bord have_male [aw=expan], row nofreq

sort indid year

save "TFR Models.dta", replace 

***How many women vary in their public sector work?

egen min_i_public=min(i_public), by(indid)
egen max_i_public=max(i_public), by(indid)

gen differ=0
replace differ=1 if max_i_public!=min_i_public

*Percentage of women who ever worked in the public sector in observation period

tabu max_i_public if c_bord==0 & c_int_length==1 [aw=expan]

tabu differ if max_i_public==1 & c_bord==0 & c_int_length==1 [aw=expan]

